atomate.feff package — atomate 0.3 documentation

# atomate.feff package

## Subpackages

- atomate.feff.firetasks package
  - Submodules
  - atomate.feff.firetasks.parse_outputs module
  - atomate.feff.firetasks.run_calc module
  - atomate.feff.firetasks.write_inputs module
  - Module contents
- atomate.feff.fireworks package
  - Submodules
  - atomate.feff.fireworks.core module
  - Module contents
- atomate.feff.workflows package
  - Submodules
  - atomate.feff.workflows.eels module
  - atomate.feff.workflows.xas module
  - Module contents

## Submodules

## atomate.feff.database module

class `atomate.feff.database.` `MMFeffDb`(host=u'localhost', port=27017, database=u'feff', collection=u'tasks', user=None, password=None)

  Bases: `atomate.utils.database.MMDb`

  `__init__`(host=u'localhost', port=27017, database=u'feff', collection=u'tasks', user=None, password=None)
  `build_indexes`(indexes=None, background=True)
  `reset`()

## atomate.feff.utils module

`atomate.feff.utils.` `get_all_absorbing_atoms`(absorbing_atom, structure)

  If the absorbing atom is specified as a string, return the list of all sites with the atomic symbol

  Args:
    absorbing_atom (str/int): site symbol or index number structure (Structure)
  Returns:
    list: list of site indices

## Module contents